Package: ViSEAGO
Version: 1.24.0
Title: ViSEAGO: a Bioconductor package for clustering biological
        functions using Gene Ontology and semantic similarity
Author: Aurelien Brionne [aut, cre],
        Amelie Juanchich [aut],
        Christelle hennequet-antier [aut]
Maintainer: Aurelien Brionne <aurelien.brionne@inrae.fr>
Imports: data.table, AnnotationDbi, dendextend, dynamicTreeCut,
        GOSemSim, GO.db, heatmaply, topGO, AnnotationForge, DT,
        DiagrammeR, R.utils, RColorBrewer, UpSetR, biomaRt, fgsea,
        ggplot2, htmlwidgets, igraph, methods, plotly, scales,
        ComplexHeatmap, circlize
Depends: R (>= 3.6)
Suggests: htmltools, org.Mm.eg.db, limma, Rgraphviz, BiocStyle, knitr,
        rmarkdown, corrplot, remotes, BiocManager, stats, utils,
        grDevices, processx
Encoding: UTF-8
Description: The main objective of ViSEAGO package is to carry out a data mining of biological functions and establish links between genes involved in the study. We developed ViSEAGO in R to facilitate functional Gene Ontology (GO) analysis of complex experimental design with multiple comparisons of interest. It allows to study large-scale datasets together and visualize GO profiles to capture biological knowledge. The acronym stands for three major concepts of the analysis: Visualization, Semantic similarity and Enrichment Analysis of Gene Ontology. It provides access to the last current GO annotations, which are retrieved from one of NCBI EntrezGene, Ensembl or Uniprot databases for several species. Using available R packages and novel developments, ViSEAGO extends classical functional GO analysis to focus on functional coherence by aggregating closely related biological themes while studying multiple datasets at once. It provides both a synthetic and detailed view using interactive functionalities respecting the GO graph structure and ensuring functional coherence supplied by semantic similarity. ViSEAGO has been successfully applied on several datasets from different species with a variety of biological questions. Results can be easily shared between bioinformaticians and biologists, enhancing reporting capabilities while maintaining reproducibility.
VignetteBuilder: knitr
License: GPL-3 bioconductor.org
URL:
        https://www.bioconductor.org/packages/release/bioc/html/ViSEAGO.html,
        https://forgemia.inra.fr/UMR-BOA/ViSEAGO
BugReports: https://forgemia.inra.fr/UMR-BOA/ViSEAGO/issues
biocViews: Software, Annotation, GO, GeneSetEnrichment,
        MultipleComparison, Clustering, Visualization
RoxygenNote: 7.3.2
Collate: 'genomic_ressource.R' 'Bioconductor2GO.R' 'Ensembl2GO.R'
        'EntrezGene2GO.R' 'EntrezGene_orthologs.R' 'enrich_GO_terms.R'
        'GO_SS.R' 'GO_clusters.R' 'GOclusters_heatmap.R' 'GOcount.R'
        'GOterms_heatmap.R' 'MDSplot.R' 'Uniprot2GO.R' 'Upset.R'
        'ViSEAGO.R' 'annotate.R' 'available_organisms.R' 'gene2GO.R'
        'build_GO_SS.R' 'clusters_cor.R' 'compare_clusters.R'
        'compute_SS_distances.R' 'create_topGOdata.R' 'custom2GO.R'
        'datasets.R' 'fgsea.R' 'merge_enrich_terms.R' 'overlapper.R'
        'pkgdiagram.R' 'runfgsea.R' 'show_heatmap.R' 'show_table.R'
        'taxonomy.R'
git_url: https://git.bioconductor.org/packages/ViSEAGO
git_branch: RELEASE_3_22
git_last_commit: 9020dee
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 07:08:33 UTC; biocbuild
