# Generated by roxygen2: do not edit by hand

export(Bioconductor2GO)
export(Custom2GO)
export(Ensembl2GO)
export(EntrezGene2GO)
export(EntrezGene_orthologs)
export(Uniprot2GO)
export(overLapper)
export(pkgdiagram)
export(taxonomy)
exportMethods(GOclusters_heatmap)
exportMethods(GOcount)
exportMethods(GOterms_heatmap)
exportMethods(MDSplot)
exportMethods(Upset)
exportMethods(annotate)
exportMethods(available_organisms)
exportMethods(build_GO_SS)
exportMethods(clusters_cor)
exportMethods(compare_clusters)
exportMethods(compute_SS_distances)
exportMethods(create_topGOdata)
exportMethods(merge_enrich_terms)
exportMethods(runfgsea)
exportMethods(show_heatmap)
exportMethods(show_table)
import(AnnotationDbi)
import(GO.db)
import(GOSemSim)
import(biomaRt)
import(data.table)
import(dendextend)
import(fgsea)
import(topGO)
importFrom(AnnotationDbi,as.list)
importFrom(AnnotationDbi,keys)
importFrom(AnnotationDbi,select)
importFrom(AnnotationDbi,species)
importFrom(AnnotationForge,loadAnnDbPkgIndex)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,max_text_width)
importFrom(ComplexHeatmap,rowAnnotation)
importFrom(DT,datatable)
importFrom(DiagrammeR,grViz)
importFrom(GO.db,GO.db)
importFrom(GO.db,GOBPANCESTOR)
importFrom(GO.db,GOBPOFFSPRING)
importFrom(GO.db,GOCCANCESTOR)
importFrom(GO.db,GOCCOFFSPRING)
importFrom(GO.db,GOMFANCESTOR)
importFrom(GO.db,GOMFOFFSPRING)
importFrom(R.utils,gunzip)
importFrom(RColorBrewer,brewer.pal)
importFrom(UpSetR,upset)
importFrom(biomaRt,getBM)
importFrom(biomaRt,listDatasets)
importFrom(biomaRt,listEnsembl)
importFrom(biomaRt,listEnsemblGenomes)
importFrom(biomaRt,listFilters)
importFrom(biomaRt,useDataset)
importFrom(biomaRt,useEnsembl)
importFrom(biomaRt,useEnsemblGenomes)
importFrom(circlize,colorRamp2)
importFrom(data.table,":=")
importFrom(data.table,.N)
importFrom(data.table,.SD)
importFrom(data.table,data.table)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(data.table,like)
importFrom(data.table,melt)
importFrom(data.table,melt.data.table)
importFrom(data.table,rbindlist)
importFrom(data.table,setorderv)
importFrom(dendextend,branches_attr_by_clusters)
importFrom(dendextend,get_leaves_attr)
importFrom(dendextend,get_nodes_attr)
importFrom(dendextend,set)
importFrom(dynamicTreeCut,cutreeDynamic)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(graphics,text)
importFrom(heatmaply,heatmaply)
importFrom(htmlwidgets,JS)
importFrom(igraph,compare)
importFrom(methods,"slot<-")
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,slot)
importFrom(plotly,add_heatmap)
importFrom(plotly,add_markers)
importFrom(plotly,export)
importFrom(plotly,layout)
importFrom(plotly,orca)
importFrom(plotly,plot_ly)
importFrom(scales,rescale)
importFrom(stats,as.dendrogram)
importFrom(stats,as.dist)
importFrom(stats,cmdscale)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,dist)
importFrom(stats,end)
importFrom(stats,hclust)
importFrom(stats,na.omit)
importFrom(stats,order.dendrogram)
importFrom(stats,start)
importFrom(topGO,inverseList)
importFrom(utils,combn)
importFrom(utils,download.file)
importFrom(utils,installed.packages)
importFrom(utils,stack)
importFrom(utils,tail)
importFrom(utils,unstack)
