#' @title myGOs dataset
#' @description  an example of object returned by \code{\link{build_GO_SS}} method
#' from mouse functional analysis of mouse mammary gland RNA-Seq (2_mouse_bioconductor vignette)
#' @docType data
#' @usage data(myGOs,package="ViSEAGO")
#' @format An object of class \code{\link{GO_SS-class}}.
"myGOs"
